:mod:`Priorites3` --- Évaluation d'une expression calculatoire
==============================================================
Le module :mod:`Priorites3` a pour objectif d'analyser une expression
calculatoire afin d'effectuer l'opération de façon détaillée en respectant les
priorités de calcul. Ce module n'utilise pas d'expressions régulières pour
analyser l'expression, afin de gagner du temps.

Ce module devra à l'avenir prendre également en charge les classes :class:`Racine` et :class:`Fractions`.

.. automodule:: pyromaths.outils.Priorites3
    :members:
    :special-members:
..    :private-members:
      :undoc-members:
      :show-inheritance:
